/*
 * LC7461M8100 simulator
 *
 * A. Hojka
 * November 2018
 * */


#ifndef MAIN_UTILS_H_
#define MAIN_UTILS_H_


/*fixed ROM code bits C6 to C12*/
#define CUSTOMCODE_MASKROM		(uint16_t)0x01

/*pin selectable part bits C0 to C5 in case of RC-550 */
#define CUSTOMCODE_PINSELECT	(uint16_t)0x13

/*entire custom code bits C0 to C12*/
#define RC550_CUSTOM_CODE 		(uint16_t)( (CUSTOMCODE_MASKROM << 6) | CUSTOMCODE_PINSELECT)



/*
 * ------------------------------------------
 *   LC7461M <-> STM32L011K4Tx - pin mapping
 *
 *   Key entry pins KI0 to KI3 and timing signal output pins KO0 to KO7 provide a key matrix of 4  8 = 32
 *   Output pin for transmit LED drive - OUT
 * ------------------------------------------
 */


/*	"Ko_0 to Ko_7 - timing signal output pins" [Output]:
 *	Ko_0	- PA5
 *	Ko_1	- PA6
 *	Ko_2	- PA7
 *	Ko_3	- PA8
 *	Ko_4	- PA9
 *	Ko_5	- PA10
 *	Ko_6	- PA11
 *	Ko_7	- PA12
 */
#define PIN_Ko_0 LL_GPIO_PIN_5
#define PIN_Ko_1 LL_GPIO_PIN_6
#define PIN_Ko_2 LL_GPIO_PIN_7
#define PIN_Ko_3 LL_GPIO_PIN_8
#define PIN_Ko_4 LL_GPIO_PIN_9
#define PIN_Ko_5 LL_GPIO_PIN_10
#define PIN_Ko_6 LL_GPIO_PIN_11
#define PIN_Ko_7 LL_GPIO_PIN_12

#define PIN_Ko0toKo7_ALL (PIN_Ko_0 | PIN_Ko_1 | PIN_Ko_2 | PIN_Ko_3 | PIN_Ko_4 | PIN_Ko_5 | PIN_Ko_6 | PIN_Ko_7)



/* "Ki_0 to Ki_3 - key entry pins" [Input - pull down]:
 *	Ki_0	- PB3
 *	Ki_1	- PB4
 *	Ki_2	- PB5
 *	Ki_3	- PB6
*/
#define PIN_Ki_0 LL_GPIO_PIN_3
#define PIN_Ki_1 LL_GPIO_PIN_4
#define PIN_Ki_2 LL_GPIO_PIN_5
#define PIN_Ki_3 LL_GPIO_PIN_6




/* "Output pin for transmit LED drive" [Output]:
 * MOD 		- PA2	(DEBUG)
 * OUT		- PA3	(38kHz PWM for IR LED)
 */
#define PIN_MOD LL_GPIO_PIN_2
#define PIN_OUT LL_GPIO_PIN_3


#define DGB_PIN_NEG() 	LL_GPIO_TogglePin(GPIOA, PIN_MOD)
#define DGB_PIN_ON() 	LL_GPIO_SetOutputPin(GPIOA, PIN_MOD)
#define DGB_PIN_OFF() 	LL_GPIO_ResetOutputPin(GPIOA, PIN_MOD)



void GPIO_cfg(void);
void GPIO_toStop(void);
void GPIO_backFromStop(void);

void CLOCK_cfg(void);
void CLOCK_backFromStop(void);

void PWR_cfg(void);
void PWR_toStop(void);

void SYSTICK_cfg(void);
void SYSTICK_toStop(void);
void SYSTICK_backFromStop(void);

void NVIC_cfg(void);
void EXTI_cfg(void);

void TIM21_cfg(void);
void TIM21_toStop(void);
void TIM21_BackFromStop(void);

void STOPModeEnter(void);
void STOPModeExit(void);




#endif /* MAIN_UTILS_H_ */
